@@ -124,23 +124,6 @@ opt_chunk_is_file = function(ctg)
 
 # ========= Processing Options ===============
 
-#' @rdname catalog_options_tools
-#' @export
-opt_cores = function(ctg)
-{
-  warning("Option no longer supported. See ?`lidR-parallelism`.", call. = FALSE)
-  return(NULL)
-}
-
-#' @rdname catalog_options_tools
-#' @export
-`opt_cores<-` = function(ctg, value)
-{
-  warning("Option no longer supported. See ?`lidR-parallelism`.", call. = FALSE)
-  return(ctg)
-}
-
-
 #' @rdname catalog_options_tools
 #' @export
 opt_progress = function(ctg)
